Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(93)

Unified Diff: ios/chrome/browser/ui/history/tab_history_popup_controller.h

Issue 2693013005: Updated tab history classes to use NavigationItemLists. (Closed)
Patch Set: update DEPS, include url_formatter in BUILD.gn Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/history/tab_history_popup_controller.h
diff --git a/ios/chrome/browser/ui/history/tab_history_popup_controller.h b/ios/chrome/browser/ui/history/tab_history_popup_controller.h
index 293447f008173811791167654f22e2c65c1ddca1..8cd8a6294a726da137ffde095372f3302d9fa002 100644
--- a/ios/chrome/browser/ui/history/tab_history_popup_controller.h
+++ b/ios/chrome/browser/ui/history/tab_history_popup_controller.h
@@ -7,20 +7,19 @@
#import "ios/chrome/browser/ui/popup_menu/popup_menu_controller.h"
-@class TabHistoryViewController;
+#include "ios/web/public/navigation_item_list.h"
// The view controller for the tab history menu that appears when the user long
// presses the back or forward button.
@interface TabHistoryPopupController : PopupMenuController
// Initializes the popup to display |entries| with the given |origin| that is
// relevant to the |parent|'s coordinate system.
// |entries| is an array of CRWSessionEntries.
-// TODO(crbug.com/546355): Convert this class to use an array of
-// NavigationEntries
- (id)initWithOrigin:(CGPoint)origin
parentView:(UIView*)parent
- entries:(NSArray*)entries;
+ items:(const web::NavigationItemList&)items
+ NS_DESIGNATED_INITIALIZER;
@end
« no previous file with comments | « ios/chrome/browser/ui/history/tab_history_cell.mm ('k') | ios/chrome/browser/ui/history/tab_history_popup_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
@@ -7,20 +7,19 @@
// presses the back or forward button.
-// Initializes the popup to display |entries| with the given |origin| that is
+// Initializes the popup to display |items| with the given |origin| that is
// relevant to the |parent|'s coordinate system.
// |entries| is an array of CRWSessionEntries.
This is Rietveld 408576698